{% extends "@FerienpassAdmin/layout/slideOverBase.html.twig" %}

{% trans_default_domain 'admin' %}

{% block main %}
    {{ component('Admin:SettleAttendances', { ids: ids, edition: edition|default(null) }) }}
{% endblock %}