<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\AdminBundle\Components;

use Ferienpass\CoreBundle\Entity\Attendance;
use Symfony\UX\LiveComponent\Attribute\AsLiveComponent;
use Symfony\UX\LiveComponent\Attribute\LiveProp;

#[AsLiveComponent(template: '@FerienpassAdmin/components/ItemActivity.html.twig', route: 'live_component_admin')]
class AttendanceActivity extends AbstractItemActivity
{
    #[LiveProp]
    public Attendance $item;

    protected function subject(): object
    {
        return $this->item;
    }
}
