<?php

declare(strict_types=1);

/*
 * This file is part of the Ferienpass package.
 *
 * (c) Richard Henkenjohann <richard@ferienpass.online>
 *
 * For more information visit the project website <https://ferienpass.online>
 * or the documentation under <https://docs.ferienpass.online>.
 */

namespace Ferienpass\AdminBundle\Tests\Form\CompoundType;

use Ferienpass\AdminBundle\Form\CompoundType\AccessCodesType;
use Ferienpass\AdminBundle\Form\CompoundType\OfferCategoriesType;
use PHPUnit\Framework\TestCase;
use Symfony\UX\LiveComponent\Form\Type\LiveCollectionType;

final class CompoundTypesTest extends TestCase
{
    public function testOfferCategoriesTypeGetParent(): void
    {
        self::assertSame(LiveCollectionType::class, new OfferCategoriesType()->getParent());
    }

    public function testAccessCodesTypeGetParent(): void
    {
        self::assertSame(LiveCollectionType::class, new AccessCodesType()->getParent());
    }
}
