{% trans_default_domain 'admin' %}
<div class="flex flex-col items-center justify-center px-6 py-16 text-center">
    <twig:ux:icon name="ph:tray" class="mb-3 size-10 text-gray-300 dark:text-gray-600" />
    <b class="text-sm font-semibold text-gray-600 dark:text-gray-300">{{ 'export.previewEmptyTitle'|trans }}</b>
    <span class="mt-1 text-xs text-gray-400">{{ 'export.previewEmptyHelp'|trans }}</span>
</div>
