<div{{ attributes }}>
    <div class="flex size-11 items-center justify-center rounded-xl bg-primary-50 text-primary-600 dark:bg-primary-900/30 dark:text-primary-300">
        <twig:ux:icon name="ph:paper-plane-tilt" class="size-6" />
    </div>

    <h3 class="mt-4 text-lg font-bold tracking-tight text-gray-900 dark:text-gray-100" id="modal-title">
        Rundmail jetzt versenden?
    </h3>
    <p class="mt-1.5 text-sm leading-6 text-gray-500 dark:text-gray-400">
        Die E-Mail wird an <b class="font-semibold text-gray-800 dark:text-gray-200">{{ numberOfEmails }} Empfänger:innen</b> zugestellt.
        Dieser Vorgang kann nicht rückgängig gemacht werden.
    </p>

    <div class="mt-6 flex justify-end gap-3">
        <twig:Admin:Button command="close" commandfor="admin-modal-dialog">Abbrechen</twig:Admin:Button>
        <twig:Admin:Button
                variant="primary"
                command="close"
                commandfor="admin-modal-dialog"
                data-action="live#emit"
                data-live-event-param="name(Admin:Mailing)|sendMailing"
                data-loading="addClass(opacity-50) addAttribute(disabled)">
            <twig:ux:icon name="ph:paper-plane-tilt" class="mr-2 size-4" />
            Endgültig versenden
        </twig:Admin:Button>
    </div>
</div>
