{% trans_default_domain 'admin' %}
{# Scope (Geltungsbereich) cell: the concrete offer/edition name an offer- or
   edition-bound consent form applies to, shown as muted context. Account-wide
   ("general") consents carry no such name and render an empty cell. #}
{% set cf = item.consentForm|default(null) %}
{% set offer = cf ? cf.offer : null %}
{% set edition = cf ? cf.edition : null %}
{% set ctx = offer ? offer.name : (edition ? edition.name : '') %}
<span class="inline-flex min-w-0 items-center gap-x-2">
    {% if ctx %}<span class="min-w-0 truncate text-gray-500 dark:text-gray-400" title="{{ ctx }}">{{ ctx }}</span>{% endif %}
</span>
