{# Fallback preview (xml / unknown exporter types): a plain list of the offers
   that would be included. #}
{% if offers is empty %}
    {{ include('@FerienpassAdmin/components/export/_preview_empty.html.twig') }}
{% else %}
    <div class="w-full max-w-[360px] divide-y divide-gray-100 overflow-hidden rounded-lg border border-gray-200 bg-white shadow-sm dark:divide-gray-800 dark:border-gray-800 dark:bg-gray-900">
        {% for offer in offers %}
            {% set d = offer.dates|first %}
            <div class="px-4 py-3">
                <b class="block truncate text-[12.5px] font-semibold text-gray-900 dark:text-gray-100">{{ offer.name }}</b>
                <div class="mt-1 flex flex-wrap gap-x-3 gap-y-1 text-[10.5px] text-gray-500 dark:text-gray-400">
                    {% if d and d.begin %}<span class="inline-flex items-center gap-1"><twig:ux:icon name="ph:calendar-blank" class="size-3" />{{ d.begin|format_datetime('medium', 'short', locale='de', timezone='Europe/Berlin') }}</span>{% endif %}
                    {% if offer.hosts is not empty %}<span class="inline-flex items-center gap-1"><twig:ux:icon name="ph:buildings" class="size-3" />{{ offer.hosts|map(h => h.name)|join(', ') }}</span>{% endif %}
                </div>
            </div>
        {% endfor %}
    </div>
{% endif %}
