{% trans_default_domain 'admin' %}
{% set translationPrefix = translationPrefix|default(app.request.attributes.get('_route')|default('')|split('_')[1]|default('base')) %}

<div class="sm:flex sm:items-start" data-modal-hide-close>
    <div class="mx-auto flex-shrink-0 flex items-center justify-center h-12 w-12 rounded-full bg-red-100 dark:bg-red-600/70 sm:mx-0 sm:h-10 sm:w-10">
        <span class="block h-6 w-6 text-red-600 dark:text-red-100/90"><twig:ux:icon name="ph:warning" /></span>
    </div>
    <div class="mt-3 text-center sm:mt-0 sm:ml-4 sm:text-left">
        <h3 class="text-lg leading-6 font-medium text-gray-900 dark:text-gray-100"
            id="modal-headline">{{ modalHeadline|default("#{translationPrefix}.deleteModal.headline")|trans({}, 'admin') }}</h3>
        <div class="mt-2">
            <p class="text-sm leading-5 text-gray-500 dark:text-gray-300">
                {{ modalConfirm|default("#{translationPrefix}.deleteModal.confirm")|trans({}, 'admin') }}
            </p>

            {% if metadata|default([]) is not empty %}
            <div class="mt-6">
                {% include '@FerienpassAdmin/fragment/_modal_dl.html.twig' %}
            </div>
            {% endif %}

            {% block content %}{% endblock %}

            {% if blocked|default(false) %}
                <div class="mt-4 rounded-md bg-red-50 dark:bg-red-900/20 p-4 ring-1 ring-red-200 dark:ring-red-800">
                    <p class="text-sm font-semibold text-red-800 dark:text-red-300">Löschen nicht möglich</p>
                    <p class="mt-1 text-sm text-red-700 dark:text-red-400">
                        Es {{ blockingReceipts|default([])|length == 1 ? 'existiert ein bezahlter Beleg' : 'existieren bezahlte Belege' }}, der bzw. die auf diese Anmeldung(en) verweist bzw. verweisen. Bezahlte Belege dürfen nachträglich nicht verändert werden.
                        {% if pseudonymizable|default(false) %}
                            Sie können stattdessen <strong>pseudonymisieren</strong>: die persönlichen Daten werden gelöscht, die Anmeldungen bleiben anonymisiert für die Belege erhalten.
                        {% else %}
                            Bitte sagen Sie das Angebot ab und erstatten Sie den Beitrag (Storno), statt es zu löschen.
                        {% endif %}
                    </p>
                    {% if blockingReceipts|default([]) is not empty %}
                        <ul class="mt-2 space-y-1">
                            {% for receipt in blockingReceipts %}
                                <li>
                                    <a href="{{ path('admin_payments_receipt', { uuid: receipt.uuid.toBase58 }) }}" data-turbo-frame="slideover" class="text-sm font-medium text-red-900 dark:text-red-200 underline hover:no-underline">
                                        Beleg #{{ receipt.receiptNumber|default('—') }}
                                    </a>
                                </li>
                            {% endfor %}
                        </ul>
                    {% endif %}
                </div>
            {% endif %}

        </div>
    </div>
</div>
<div class="mt-5 sm:mt-4 sm:ml-10 sm:flex sm:pl-4 sm:gap-3">

    {% if not blocked|default(false) or pseudonymizable|default(false) %}
        {{ form_start(form) }}

        {% if not blocked|default(false) %}
            <twig:Admin:Button type="submit" variant="destructive" class="w-full sm:w-auto justify-center">
                {{ modalSubmit|default("#{translationPrefix}.deleteModal.submit")|trans({}, 'admin') }}
            </twig:Admin:Button>
        {% endif %}

        {% if pseudonymizable|default(false) %}
            <twig:Admin:Button type="submit" name="_action" value="pseudonymize" variant="{{ blocked|default(false) ? 'primary' : 'secondary' }}" class="mt-3 sm:mt-0 w-full sm:w-auto justify-center">
                Pseudonymisieren
            </twig:Admin:Button>
        {% endif %}

        {{ form_end(form) }}
    {% endif %}

    <form method="dialog">
        <twig:Admin:Button type="submit" class="mt-3 sm:mt-0 w-full sm:w-auto justify-center">
            {{ blocked|default(false) ? 'Schließen' : 'Abbrechen' }}
        </twig:Admin:Button>
    </form>
</div>
