{% extends "@FerienpassAdmin/layout/slideOverBase.html.twig" %}
{% trans_default_domain 'admin' %}
{% set title = item.participant ? item.participant.name : ('attendanceShow.deletedParticipant'|trans({}, 'admin')) %}

{% block main %}
    <twig:Admin:AttendanceShow :attendance="item" />
{% endblock %}
