{% extends "@FerienpassAdmin/layout/base.html.twig" %}
{% trans_default_domain 'admin' %}
{% set title = 'outbox.title' %}

{% block main %}

    <twig:Admin:PageHeader title="outbox.title" subtitle="outbox.subtitle">
        <twig:block name="actions">
            <twig:Admin:Button href="{{ path('admin_tools_mailing') }}" variant="primary">
                <twig:ux:icon name="ph:paper-plane-tilt" class="-ml-0.5 mr-1.5 size-4" />
                {{ 'outbox.action.compose'|trans({}, 'admin') }}
            </twig:Admin:Button>
        </twig:block>
    </twig:Admin:PageHeader>

    <div class="py-6">
        <twig:Admin:Outbox />
    </div>

{% endblock %}
