{% trans_default_domain 'admin' %}
{# Fetched by the lazy frame a row's dropdown carries; see ListActionsController. #}
<turbo-frame id="{{ frame }}">
    {% set actions = list_actions(item, [], { view: view, edition: edition }) %}
    {% set actions = actions.children|filter(a => a.displayed) %}

    {% if actions|length > 0 %}
        {% include '@FerienpassAdmin/components/_list_actions_menu.html.twig' with { actions: actions } only %}
    {% else %}
        <div class="px-3 py-2 text-sm text-gray-500 dark:text-gray-400">{{ 'list.noActions'|trans }}</div>
    {% endif %}
</turbo-frame>
